
BEGIN TRANSACTION;


CREATE TABLE series (
	id_on_server                         TEXT,
	running_time                         INTEGER,
	disc_running_time                    INTEGER,
	rating                               REAL,
	network                              TEXT,
	first_aired                          INTEGER,
	status                               TEXT,
	air_time                             INTEGER,
	country_id                           INTEGER,
	data_changed                         INTEGER,

	country_first_aired                  INTEGER,
	country_air_day                      INTEGER,
	country_air_time                     INTEGER,
	country_running_time                 INTEGER,
	country_parental_rating              INTEGER     DEFAULT -1,
	country_status                       TEXT,
	country_network                      TEXT,
	country_country_id                   INTEGER,
	country_data_changed                 INTEGER,

	description                          TEXT,
	title                                TEXT,
	sort_title                           TEXT,
	language                             TEXT,
	language_data_changed                INTEGER,
	language_data_changed_en             INTEGER,
	en_fields                            TEXT,

	_rating                              INTEGER,
	_disc_connected                      INTEGER,
	_online                              INTEGER     DEFAULT 0,
	_added_date                          INTEGER     DEFAULT 0,
	_group_id                            INTEGER,
	_collection_num                      INTEGER,
	_checked                             INTEGER     DEFAULT 0,
	_only_on_disc_title                  INTEGER     DEFAULT 0,
	_last_episode_added                  INTEGER,
	_last_episode_personal_data_changed  INTEGER,
	_posterHash                          TEXT,
	_data_changed                        INTEGER
);
CREATE INDEX idx_series_title         ON series (title);
CREATE INDEX idx_series_id_on_server  ON series (id_on_server);
CREATE INDEX idx_series_group_id      ON series (_group_id);
CREATE INDEX idx_series_country_id    ON series (country_id);


CREATE TABLE remotes (
	serie_id    INTEGER,
	episode_id  INTEGER,
	name        TEXT     NOT NULL,
	id          TEXT     NOT NULL	
);
CREATE INDEX idx_remotes_serie_id ON remotes (serie_id);
CREATE INDEX idx_remotes_episode_id ON remotes (episode_id);


CREATE TABLE episodes (
	serie_id                    INTEGER,
	id_on_server                TEXT,
	rating                      REAL,
	season_number               INTEGER,
	episode_number              INTEGER,
	production_code             INTEGER,
	absolut_number              INTEGER,
	dvddisc_id                  TEXT,
	dvdseason                   INTEGER,
	dvdepisode_number           INTEGER,
	dvdchater                   INTEGER,
	data_changed                INTEGER,
	first_aired                 INTEGER,
	first_aired_country         TEXT,
	data_loaded                 INTEGER    DEFAULT 0,
	cover_loaded                INTEGER    DEFAULT 0,
	
	country_first_aired         INTEGER,
	country_country_id          INTEGER,
	country_data_changed        INTEGER,

	description                 TEXT,
	title                       TEXT,
	sort_title                  TEXT,
	language                    TEXT,
	language_data_changed       INTEGER,
	language_data_changed_en    INTEGER,
	en_fields                   TEXT,

	_rating                     INTEGER,
	_disc_connected             INTEGER,
	_standalone                 INTEGER,
	_owned                      INTEGER     DEFAULT 0,
	_online                     INTEGER     DEFAULT 0,
	_added_date                 INTEGER,
	_data_changed               INTEGER,
	_title_locations            TEXT,
	_dune_paths                 TEXT,
	_imageHash                  TEXT
);
CREATE INDEX idx_episodes_title         ON episodes (title);
CREATE INDEX idx_episodes_id_on_server  ON episodes (id_on_server);
CREATE INDEX idx_episodes_serie_id      ON episodes (serie_id);

// wrong one (does not exist in database):
CREATE TABLE title_episodes (
	title_id                INTEGER,
	disc_id                 INTEGER,
	season_number           INTEGER,
	episode_number          INTEGER
);
CREATE INDEX idx_title_episodes_title_id ON title_episodes (title_id);
CREATE INDEX idx_title_episodes_disc_id ON title_episodes (disc_id);


CREATE TABLE persons_backup (
	title_id    INTEGER,
    serie_id    INTEGER,
	episode_id  INTEGER,
	name        TEXT NOT NULL,
	type        INTEGER,
	role        TEXT,
	sort        INTEGER NOT NULL DEFAULT 0
);
INSERT INTO persons_backup SELECT title_id, null, null, name, type, role, sort FROM persons;
DROP TABLE persons;
ALTER TABLE persons_backup RENAME TO persons;

CREATE INDEX idx_persons_title_id ON persons (title_id);
CREATE INDEX idx_persons_serie_id ON persons (serie_id);
CREATE INDEX idx_persons_episode_id ON persons (episode_id);
CREATE INDEX idx_persons_name ON persons (name);


CREATE TABLE titles_backup (
    id_on_server               TEXT,
    serie_id_on_server         TEXT,
    parent_id_on_server        TEXT,
    is_box_set_on_server       INTEGER     DEFAULT 0,
    title                      TEXT,
    original_title             TEXT, 
    sort_title                 TEXT, 
    country_id                 INTEGER,
    type_id                    INTEGER,
    barcode                    TEXT,
    running_time               INTEGER, 
    production_year            INTEGER, 
    description                TEXT,
    release_date               INTEGER, 
    parental_rating            INTEGER     DEFAULT -1,
    parental_description       TEXT,
    aspect_ratio               TEXT, 
    video_standard             TEXT, 
    imdb_id                    TEXT, 
    extra_features             TEXT,
    rating                     REAL,  
    data_changed               INTEGER,
    covers_changed             INTEGER, 
    data_locked                INTEGER     DEFAULT 0,
    covers_locked              INTEGER     DEFAULT 0,  
    is3D                       INTEGER     DEFAULT 0,
    edition                    TEXT,
    media_type                 TEXT,
    work_as_tvseries           INTEGER     DEFAULT 0,

    _group_id                  INTEGER,
    _collection_num            INTEGER,
    _online                    INTEGER     DEFAULT 0,
    _personal                  INTEGER     DEFAULT 0,
    _added_date                INTEGER     DEFAULT 0,
    _lent_to                   TEXT,
    _lent_due                  INTEGER,
    _title                     TEXT,
    _sort_title                TEXT,
    _rating                    INTEGER,
    _location                  TEXT,
    _purchase_date             INTEGER,
    _purchase_price            REAL, 
    _purchase_curr             TEXT,
    _purchase_place            TEXT, 
    _value_date                INTEGER,
    _value_price               REAL,
    _value_curr                TEXT, 
    _condition                 TEXT, 
    _notes                     TEXT, 
    _tags                      TEXT,
    _exclude_online_collection INTEGER     DEFAULT 0,
    _exclude_mobile_software   INTEGER     DEFAULT 0,
    _invisible_to_friends      INTEGER     DEFAULT 0,
    _title_locations           TEXT,
    _dune_paths                TEXT,
    _checked                   INTEGER     DEFAULT 0,
    _data_changed              INTEGER,
    _xbmc_paths                TEXT
);
INSERT INTO titles_backup SELECT id_on_server, null, null, null, title, original_title, sort_title, country_id,
    type_id, barcode, running_time, production_year, description, release_date, parental_rating,
    parental_description, aspect_ratio, video_standard, imdb_id, extra_features, rating, null, null, 
    data_locked, covers_locked, is3D, edition, media_type, null,
    group_id, collection_num, online, personal, added, lent_to, lent_due,
    _title, _sort_title, _rating, _location, _purchase_date, null, _purchase_curr, _purchase_place,
    _value_per, null, _value_curr, _condition, _notes, _tags, null, null, null, _title_locations, _dune_paths, null, null, null FROM titles;
DROP TABLE titles;
ALTER TABLE titles_backup RENAME TO titles;

CREATE INDEX idx_titles_original_title  ON titles (original_title);
CREATE INDEX idx_titles_title           ON titles (title);
CREATE INDEX idx_titles__title          ON titles (_title);
CREATE INDEX idx_titles__tags           ON titles (_tags);
CREATE INDEX idx_titles__notes          ON titles (_notes);
CREATE INDEX idx_titles_group_id        ON titles (_group_id);
CREATE INDEX idx_titles_type_id         ON titles (type_id);
CREATE INDEX idx_titles_country_id      ON titles (country_id);
CREATE INDEX idx_titles_id_on_server    ON titles (id_on_server);


CREATE TABLE items_genres (
     title_id               INTEGER,
     serie_id               INTEGER,
     genre_id               INTEGER NOT NULL);

INSERT INTO items_genres SELECT title_id, null, genre_id FROM titles_genres;
DROP TABLE titles_genres;

CREATE INDEX idx_items_genres_title_id ON items_genres (title_id);
CREATE INDEX idx_items_genres_serie_id ON items_genres (serie_id);
CREATE INDEX idx_items_genres_genre_id ON items_genres (genre_id);


CREATE TABLE watchedEvents_backup (
     title_id               INTEGER,
     episode_id             INTEGER,
     date                   INTEGER      NOT NULL,
     name                   TEXT, 
     notes                  TEXT
);
INSERT INTO watchedEvents_backup SELECT title_id, null, date, name, notes FROM watchedEvents;
DROP TABLE watchedEvents;
ALTER TABLE watchedEvents_backup RENAME TO watchedEvents;

CREATE INDEX idx_watchedEvents_title_id ON watchedEvents (title_id);
CREATE INDEX idx_watchedEvents_episode_id ON watchedEvents (episode_id);


CREATE TABLE audiotracks_backup (
    title_id                INTEGER     NOT NULL, 
    language                TEXT        NOT NULL,
    type                    TEXT, 
    channels                TEXT, 
    sort                    INTEGER     NOT NULL
);
INSERT INTO audiotracks_backup SELECT * FROM audiotracks;
DROP TABLE audiotracks;
ALTER TABLE audiotracks_backup RENAME TO audiotracks;

CREATE INDEX idx_audiotracks_title_id ON audiotracks (title_id);

CREATE TABLE android_metadata (locale TEXT DEFAULT 'en_US');
CREATE TABLE "media_types" (name TEXT NOT NULL, localized_name TEXT);
ALTER TABLE countries ADD COLUMN localized_name TEXT;
ALTER TABLE genres ADD COLUMN localized_name TEXT;
ALTER TABLE groups ADD COLUMN localized_name TEXT;

UPDATE groups SET name = 'Previously Owned' WHERE name = 'Pre-Owned';
UPDATE groups SET name = 'Previously Rented' WHERE name = 'Pre-Rented';

COMMIT;
